@@ -53,9 +53,15 @@ struct _GtkHTMLPrivate {
 
 	GtkIMContext *im_context;
 	gboolean need_im_reset;
+	gint im_pre_len;
+	gint im_pre_pos;
+	GtkHTMLFontStyle im_orig_style;
+	gboolean im_block_reset;
 
 	HTMLObject *dnd_object;
+	gint        dnd_object_offset;
 	HTMLObject *dnd_real_object;
+	gint        dnd_real_object_offset;
 	gboolean    dnd_in_progress;
 	gchar      *dnd_url;
 
@@ -65,18 +71,26 @@ struct _GtkHTMLPrivate {
 	gboolean    magic_links;
 	gboolean    magic_smileys;
 	gboolean    inline_spelling;
+
+	gulong      toplevel_unmap_handler;
+
+	gboolean in_object_resize;
+	GdkCursor *resize_cursor;
+	HTMLObject *resize_object;
 };
 
-void  gtk_html_private_calc_scrollbars  (GtkHTML                 *html,
-					 gboolean                *changed_x,
-					 gboolean                *changed_y);
-void  gtk_html_editor_event_command     (GtkHTML                 *html,
-					 GtkHTMLCommandType       com_type,
-					 gboolean                 before);
-void  gtk_html_editor_event             (GtkHTML                 *html,
-					 GtkHTMLEditorEventType   event,
-					 GValue                  *args);
-void  gtk_html_api_set_language         (GtkHTML                 *html);
-void  gtk_html_im_reset                 (GtkHTML                 *html);
+void  gtk_html_private_calc_scrollbars  (GtkHTML                *html,
+					 gboolean               *changed_x,
+					 gboolean               *changed_y);
+void  gtk_html_editor_event_command     (GtkHTML                *html,
+					 GtkHTMLCommandType      com_type,
+					 gboolean                before);
+void  gtk_html_editor_event             (GtkHTML                *html,
+					 GtkHTMLEditorEventType  event,
+					 GValue                 *args);
+void  gtk_html_api_set_language         (GtkHTML                *html);
+void  gtk_html_im_reset                 (GtkHTML                *html);
+void  gtk_html_set_fonts                (GtkHTML                *html,
+					 HTMLPainter            *painter);
 
 #endif /* _GTKHTML_PRIVATE_H */
